package com.docus.server.collect.user.http;

import com.docus.core.util.json.JSON;
import com.docus.infrastructure.web.api.CommonResult;
import com.docus.log.annotation.TrackGroup;
import com.docus.log.context.TrackHelper;
import com.docus.server.collect.IConverter;
import com.docus.server.collect.IHttpResult;
import com.docus.server.collect.web.enums.CollectTypeEnum;
import com.docus.server.collect.web.processor.VisitorProcessor;
import com.docus.server.collect.web.service.CollectService;
import com.docus.server.sys.common.pojo.dto.UserDTO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;


/**
 * @author wen yongbin
 * @date 2023年2月25日21:56:33
 * @see CollectTypeEnum 枚举
 * @see IConverter 通用转化器
 * @see IHttpResult 通用返回结果
 * @see VisitorProcessor 通用处理器
 */

@Api(value = "用户管理接口", tags = "用户管理接口")
@Slf4j
@RestController
@RequestMapping("/api/rest/user")
public class UserRestController {
    @Resource
    private CollectService collectService;

    /**
     * 被动http 用户信息接收，进行操作
     *
     * @param message 接收到的用户参数
     * @return 返回结果
     */
    @ApiOperation("新增/编辑用户(根据用户工号)")
    @PostMapping("/update")
    @TrackGroup(
        group = "HTTP_PASSIVE_USER",
        beanNames = {"httpUserConverter", "httpUserResultImpl"},
        processor = VisitorProcessor.class)
    public CommonResult httpPassiveUser(@RequestBody String message) {
        log.info("新增/修改用户数据：{}", message);
        collectService.insertOrUpdateUser(JSON.fromJSON((String) TrackHelper.getValue("jsonStr"), UserDTO.class));
        return null;
    }
}
