package com.docus.server.collect.user.mq.impl;

import com.docus.core.util.json.JSON;
import com.docus.log.annotation.TrackGroup;
import com.docus.log.context.TrackHelper;
import com.docus.server.collect.user.mq.IUserMqCollectService;
import com.docus.server.collect.web.processor.VisitorProcessor;
import com.docus.server.collect.web.service.CollectService;
import com.docus.server.sys.common.pojo.dto.UserDTO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 每家mq 都不一样，这部分无法预先写好写入，需要根据每家独立编写。
 */
@Slf4j
@Service("userJmsMqCollectServiceImpl")
public class UserJmsMqCollectServiceImpl implements IUserMqCollectService {

    @Resource
    private CollectService collectService;

    /**
     * 订阅队列（注册人员）
     *
     * @param message 人员信息
     */
    @Override
    @TrackGroup(
        group = "JMS_MQ_PASSIVE_INSERT_USER",
        beanNames = {"mqUserConverter", "mqUserResultImpl"},
        processor = VisitorProcessor.class)
    public void addUser(String message) {
        log.info("人员注册 队列接收信息：{}", message);
        collectService.insertOrUpdateUser(getValue());
    }

    /**
     * 订阅队列（变更人员）
     *
     * @param message 人员信息
     */
    @Override
    @TrackGroup(
        group = "JMS_MQ_PASSIVE_UPDATE_USER",
        beanNames = {"mqUserConverter", "mqUserResultImpl"},
        processor = VisitorProcessor.class)
    public void updateUser(String message) {
        log.info("人员变更 队列接收信息：{}", message);
        collectService.insertOrUpdateUser(getValue());
    }

    public UserDTO getValue() {
        return JSON.fromJSON((String) TrackHelper.getValue("jsonStr"), UserDTO.class);
    }
}
