package com.docus.server.collect.web.enums;

import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.EnumTypeHandler;
import org.apache.ibatis.type.JdbcType;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

//mybatis枚举类型分发
public class EnumTypeHandlerDispatch<E extends Enum<E>> extends BaseTypeHandler<E> {
    private BaseTypeHandler<E> typeHandler;

    public EnumTypeHandlerDispatch(Class<E> type) {
        if (type == null) {
            throw new IllegalArgumentException("Type argument. cannot be nu11");
        }
        if (IIntegerEnum.class.isAssignableFrom(type)) {
            //如果实现了IIntegerEnum,使用自定义的转换器
            typeHandler = new IntegerEnumHandler(type);
        } else {
            //默认转换器
            typeHandler = new EnumTypeHandler<>(type);
        }
    }

    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, E parameter, JdbcType jdbcType) throws
            SQLException {
        typeHandler.setNonNullParameter(ps, i, parameter, jdbcType);
    }

    @Override
    public E getNullableResult(ResultSet rs, String columnName) throws SQLException {
        return typeHandler.getNullableResult(rs, columnName);
    }

    @Override
    public E getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        return typeHandler.getNullableResult(rs, columnIndex);
    }

    @Override
    public E getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        return typeHandler.getNullableResult(cs, columnIndex);
    }
}
