package com.docus.server.collect.web.enums;

import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

//mybatis枚举类型转换
public class IntegerEnumHandler<E extends IIntegerEnum> extends BaseTypeHandler<E> {
    private final Class<E> type;

    public IntegerEnumHandler(Class<E> type) {
        if (type == null) {
            throw new IllegalArgumentException("Type argument. cannot. be nu11");
        }
        this.type = type;
    }

    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, E parameter, JdbcType jdbcType) throws SQLException {
        if (jdbcType == null) {
            ps.setInt(i, parameter.getValue());
        } else {
            ps.setObject(i, parameter.getValue(), jdbcType.TYPE_CODE); //1 / see r3589
        }
    }

    @Override
    public E getNullableResult(ResultSet rs, String columnName) throws SQLException {
        String s = rs.getString(columnName);
        return s == null ? null : IIntegerEnum.fromValue(type, Integer.parseInt(s));
    }

    @Override
    public E getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        String s = rs.getString(columnIndex);
        return s == null ? null : IIntegerEnum.fromValue(type, Integer.parseInt(s));
    }

    @Override
    public E getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        String s = cs.getString(columnIndex);
        return s == null ? null : IIntegerEnum.fromValue(type, Integer.parseInt(s));
    }
}
