package com.docus.server.collect.web.job;

import com.docus.core.util.Func;
import com.docus.server.collect.IJob;
import com.docus.server.collect.web.domain.TaskConfig;
import com.docus.server.collect.web.service.ITaskConfigService;
import com.docus.server.collect.web.utils.PeriodTime;
import com.docus.server.record.service.ITBasicService;
import com.docus.server.sys.service.IPowerDeptService;
import com.docus.server.sys.service.IPowerUserService;
import com.xxl.job.core.context.XxlJobHelper;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

public abstract class AbstractCollectJob<T> implements IJob<T> {
    @Resource
    protected IPowerUserService userService;
    @Resource
    protected IPowerDeptService deptService;
    @Autowired
    protected ITBasicService basicService;
    @Resource
    protected ITaskConfigService taskConfigService;

    @Override
    public void startCollectAll(String taskConfigId) {
        TaskConfig taskConfig = taskConfigService.getTaskConfig(taskConfigId);

        List<PeriodTime> periodTimes = taskConfig.getAllPeriodTimes();
        for (PeriodTime periodTime : periodTimes) {
            get(periodTime, taskConfig);
            taskConfigService.updateAllPointerDate(taskConfigId, periodTime.getPeriodEndDate());
        }
    }

    @Override
    public void startCollectIncrement(String taskConfigId) {
        TaskConfig taskConfig = taskConfigService.getTaskConfig(taskConfigId);

        List<PeriodTime> periodTimes = taskConfig.getIncPeriodTimes();
        periodTimes.forEach(periodTime -> {
            get(periodTime, taskConfig);
            taskConfigService.updateIncPointerDate(taskConfigId, periodTime.getPeriodEndDate());
        });

    }

    @Override
    public void get(PeriodTime periodTime, TaskConfig taskConfig) {
        //考虑到性能，应该把起始时间和结束时间进行切割拆分到每天。按段查询。
        List<T> t;
        int pageNum = 1;
        for (; true; pageNum++) {
            t = this.execute(
                periodTime.getPeriodStartDate(),
                periodTime.getPeriodEndDate(),
                pageNum,
                taskConfig.getPageSize()
            );
            if (Func.isEmpty(t)) {
                break;
            }

            this.batchInsertOrUpdate(t);
        }
    }

    protected String getJobParam() {
        return XxlJobHelper.getJobParam();
    }

    public abstract void batchInsertOrUpdate(List<T> t);

    public abstract List<T> execute(Date startDate, Date endDate, long pageNum, long pageSize);
}
